#
# spec file for package wlc
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define wayland_minimal 1.7
Name:           wlc
Version:        0.0.11
Release:        lp152.5.4
Summary:        A Wayland Compositor Library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/Cloudef/wlc
Source0:        https://github.com/Cloudef/wlc/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Source1:        https://github.com/Cloudef/wlc/releases/download/v%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  Mesa-devel
BuildRequires:  chck-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client) >= %{wayland_minimal}
BuildRequires:  pkgconfig(wayland-cursor) >= %{wayland_minimal}
BuildRequires:  pkgconfig(wayland-egl) >= %{wayland_minimal}
BuildRequires:  pkgconfig(wayland-protocols) >= %{wayland_minimal}
BuildRequires:  pkgconfig(wayland-scanner) >= %{wayland_minimal}
BuildRequires:  pkgconfig(wayland-server) >= %{wayland_minimal}
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-dpms)
BuildRequires:  pkgconfig(xcb-dri2)
BuildRequires:  pkgconfig(xcb-dri3)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-glx)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-present)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-record)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-res)
BuildRequires:  pkgconfig(xcb-screensaver)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-sync)
BuildRequires:  pkgconfig(xcb-xf86dri)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xcb-xtest)
BuildRequires:  pkgconfig(xcb-xv)
BuildRequires:  pkgconfig(xcb-xvmc)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(zlib)

%description
A Wayland compositor library. Used by sway or orbment.

%package -n libwlc0
Summary:        A Wayland Compositor Library
Group:          System/Libraries

%description -n libwlc0
Wayland Compositor Library itself.

%package devel
Summary:        Development files for the wlc Wayland Compositor Library
Group:          Development/Libraries/C and C++
Requires:       chck-devel
Requires:       cmake
Requires:       libwlc0 = %{version}
Requires:       pkgconfig(wayland-client) >= %{wayland_minimal}
Requires:       pkgconfig(wayland-cursor) >= %{wayland_minimal}
Requires:       pkgconfig(wayland-egl) >= %{wayland_minimal}
Requires:       pkgconfig(wayland-scanner) >= %{wayland_minimal}
Requires:       pkgconfig(wayland-server) >= %{wayland_minimal}

%description devel
Development files for Wayland Compositor Library.

%prep
%setup -q

# make sure that chck from tarball is not used
rm -r lib/chck/*

%build
%cmake \
       -DSOURCE_CHCK=OFF

make %{?_smp_mflags}

%install
%cmake_install

%post   -n libwlc0 -p /sbin/ldconfig
%postun -n libwlc0 -p /sbin/ldconfig

%files -n libwlc0
%license LICENSE
%doc README.rst
%{_libdir}/libwlc.so.*

%files devel
%{_libdir}/libwlc.so
%{_libdir}/pkgconfig/wlc.pc
%{_includedir}/wlc/

%changelog
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly require xfixes at build time.
* Thu Nov  9 2017 aavindraa@gmail.com
- bump to 0.0.11
  - Increment version to 3 for data_(offer|source|device) too
  - Add support for wl_data_(offer|source).set_actions
  - Add support for wl_data_offer.finish
  - Make wl_data_device_manager version 3
  - Fix xwm selection release
    In case xwayland terminates before compositor xwm activated,
    xwm selection listener link is invalid. This causes crash in
    `wlc_xwm_selection_release`.
  - Add elogind support
- cleanup with spec-cleaner
* Thu Oct 19 2017 sleep_walker@opensuse.org
- bump to 0.0.10
  - add elogind support
  - fix xwm selection related bugs
  - begin implementation of drag&drop
* Thu Sep 14 2017 zaitor@opensuse.org
- Add explicit pkgconfig(libudev) BuildRequires: Mandatory
  dependency previously pulled in by something else.
* Thu May  4 2017 sleep_walker@opensuse.org
- bump to 0.0.9
  see git log for complete list of changes
* Tue Feb 28 2017 sleep_walker@opensuse.org
- bump to 0.0.8
  Add fireplace window manager and bindings to README
  Fix: ... and calling wlc_xdg_positioner_protocol_set_constraint_adjustment
    sets anchor too
  Fix: Calling wlc_xdg_positioner_protocol_set_gravity
    actually sets anchor
  wlc: Use eglGetPlatformDisplayEXT where available
  Feature: add wlc_view_get_instance()
  Fully implemented xdg-positioner and added getters for
    stored data. Fixes Cloudef/wlc#210
  Implemented skelet of xdg-positioner, responds to
    requests, but stores no data.
  Turned non-implemented xdg_cb_popup_grab into warning
  Use WM_CLASS class instead of instance
  Include sys/sysmacros.h for major/minor(3) (Linux)
  Fix error in precondition
  Add gamma control API
  Fix XWayland and security on FreeBSD
  CMake: s/WLPROTO/WAYLANDPROTOCOLS/
  CMake: Fix FindWaylandProtocol.cmake
  CMake: Move FindPackage(WaylandProtocols) to root
* Mon Dec 12 2016 dimstar@opensuse.org
- Drop pkgconfig(libsystemd-daemon), pkgconfig(libsystemd-id128),
  pkgconfig(libsystemd-journal) and pkgconfig(libsystemd-login)
  BuildRequires: cmake only checks for the presence of libsystemd.
* Wed Oct 26 2016 sleep_walker@opensuse.org
- bump to 0.0.7
  partially implement xdg-shell v6
  surface: Fix bad use of wlc_size_max
* Tue Sep 27 2016 sleep_walker@opensuse.org
- bump to 0.0.6
  submodule: Update wayland-protocols
  flip vertical coordinates in read_pixels()
  Fix: Inform X11 windows about border size.
  output: Set backend surface only after creation
  cmake: Constant for LINUX doesn't exist
  keymap: Invalidate fd on release
  keymap: Zero out structure on release
  Changes to enable building on FreeBSD. Need to confirm still builds
    and works as expected on Linux!
  Include way-cooler in README
* Tue Aug  2 2016 sleep_walker@opensuse.org
- bump to 0.0.5
  implement wlc_view_get_pid()
  xwm: do not try to focus override_redirect windows
  keyboard: Send focus out only on way<->x11 change
  view: Return visible geo as input area for x views
* Sun Jul 31 2016 sleep_walker@opensuse.org
- bump to 0.0.4
  Bump version to 0.0.4
    HiDPI, surface and subsurface related features and fixes
    s/wlc_resource/wlc_handle/
    Remove spammy debug log.
    add WLC_DRAW_INPUT env var
    xwm features
    (for complete list of changes check git log)
* Mon May 30 2016 sleep_walker@opensuse.org
- drop build requirements of xcb-xevie and xcb-xprint
* Mon May 23 2016 sleep_walker@opensuse.org
- bump to 0.0.3
  view property related changes
  bugfixes
  build related improvements
  use XDG_SEAT instead of seat0
* Thu May  5 2016 sleep_walker@opensuse.org
- removing the changes which doesn't seem to be necessary anymore
* Thu Apr 21 2016 sleep_walker@opensuse.org
- bump to release 0.0.2
- wipe included chck from sources (it is packaged separately)
- add LICENSE and README.rst to package
* Fri Apr 15 2016 sleep_walker@opensuse.org
- new git snapshot (2016-04-10, 309ddb0)
  gles2 related improvements
  bygfixes
* Sat Feb 27 2016 sleep_walker@opensuse.org
- new git snapshot (2016-02-26, 651ebc8)
  add golang and rust bindings
  use system Wayland protocols
* Thu Feb  4 2016 sleep_walker@opensuse.org
- new git snapshot (2016-01-31, faa4d3c)
  xwayland - xwm related changes
  build related changes
  output related changes
- add xcb-ewmh among BuildRequires
- FindWlc.cmake no longer provided
* Wed Jan 20 2016 sleep_walker@opensuse.org
- new git snapshot (2016-01-14, 1bc4558)
  fix touchscreen crashes
  fix repeat keys
* Wed Jan  6 2016 sleep_walker@opensuse.org
- new git snapshot (2016-01-05, e9f20ef)
  close XWayland before closing compositor
  C++ support
  Update keyboard leds when pressed
* Thu Dec 17 2015 sleep_walker@opensuse.org
- new git snapshot (2015-12-15, cff1917)
  xwm: bring focused window always above others
  xwm/output: hack around "invisible" x11 windows
  ...
* Mon Nov 23 2015 sleep_walker@opensuse.org
- explicitly require wayland for wlc-devel
- add wayland-egl
* Mon Nov 23 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-19, 3b836aa)
  remove background code and configuration
* Tue Nov 17 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-14, 9daf696)
  wlc: remove output connector and id from public
  output: no-op wlc_output_focus with 0 argument.
  pointer.c: clamp pointer to output when rendering
  wlc: Change naming conventions to avoid confusion
  wlc_pointer_motion no longer needs new position.
  output.c: Do not attach views without buffers
  xwm.c: Add more debug output.
  cmake: whitespace
  output.c: Cancel repaints on bsurface removal
  output.c: Remove spurious memset
  example: Update/fix, set pointer origin.
  Fixed window naming
* Thu Oct 29 2015 sleep_walker@opensuse.org
- new git snapshot (2015-10-28, a30a674)
* Tue Oct 27 2015 sleep_walker@opensuse.org
- new git snapshot (1852992, 2015-10-23)
  - pointer set API, client is responsible for updating pointer
* Thu Oct  8 2015 sleep_walker@opensuse.org
- require wayland 1.7+ as stated in README
* Wed Oct  7 2015 sleep_walker@opensuse.org
- use %%{_libdir} macro instead of hardcoded /usr/lib64 to fix i586
  build
* Sat Sep 26 2015 sleep_walker@opensuse.org
- read .so symlinks from build environment and patch the source code
  accordingly
* Tue Sep 22 2015 sleep_walker@opensuse.org
- until there is better implementation require devel packages
  to have symlinks to .so files
* Sat Sep 19 2015 sleep_walker@opensuse.org
- require xcb-image
* Sat Sep 19 2015 sleep_walker@opensuse.org
- instead of using internal chck library use systemwide installed one
- remove xkbcommon-path.patch
* Thu Sep 17 2015 sleep_walker@opensuse.org
- add xkbcommon-path.patch to fix upstream expectation about the
  path to the header
* Thu Sep 17 2015 sleep_walker@opensuse.org
- use download service to get the tarball
- remove patch (it reached upstream)
  properly-detect-and-handle-includedirs.patch
* Thu Sep  3 2015 sleep_walker@opensuse.org
- enable building examples and tests again
- reformat using spec-cleaner
* Thu Sep  3 2015 sleep_walker@opensuse.org
- and now it builds without more correct patch
  properly-detect-and-handle-includedirs.patch
* Mon Aug 24 2015 sleep_walker@opensuse.org
- and now it even builds
* Fri Aug 21 2015 sleep_walker@opensuse.org
- let there be wlc!
